---
title: کامپوننت فراخوانی
linkTitle: فراخوانی
aliases:
- فراخوانی‌ها
---

یک کامپوننت داخلی برای نشان دادن اطلاعات مهم به خواننده.

<!--more-->

## مثال

{{< callout emoji="👾">}}
  **فراخوانی** یک متن کوتاه است که برای جلب توجه در نظر گرفته شده است.
{{< /callout >}}

{{< callout type="info" >}}
  **فراخوانی** یک متن کوتاه است که برای جلب توجه در نظر گرفته شده است.
{{< /callout >}}

{{< callout type="warning" >}}
  **فراخوانی** یک متن کوتاه است که برای جلب توجه در نظر گرفته شده است.
{{< /callout >}}

{{< callout type="error" >}}
  **فراخوانی** یک متن کوتاه است که برای جلب توجه در نظر گرفته شده است.
{{< /callout >}}

## استفاده

### پیش‌فرض

{{< callout emoji="🌐">}}
  Hugo را می‌توانید برای ایجاد طیف گسترده‌ای از وب‌سایت‌ها، از جمله وبلاگ‌ها، نمونه‌کارها، سایت‌های مستندسازی و غیره استفاده کرد.
{{< /callout >}}

```markdown
{{</* callout emoji="🌐" */>}}
  Hugo را می‌توانید برای ایجاد طیف گسترده‌ای از وب‌سایت‌ها، از جمله وبلاگ‌ها، نمونه‌کارها، سایت‌های مستندسازی و غیره استفاده کرد.
{{</* /callout */>}}
```

### اطلاعات

{{< callout type="info" >}}
  لطفا برای مشاهده آخرین نسخه‌ها به گیت‌هاب مراجعه کنید.
{{< /callout >}}

```markdown
{{</* callout type="info" */>}}
  لطفا برای مشاهده آخرین نسخه‌ها به گیت‌هاب مراجعه کنید.
{{</* /callout */>}}
```

### هشدار

{{< callout type="warning" >}}
  این API در نسخه بعدی منسوخ خواهد شد.
{{< /callout >}}

```markdown
{{</* callout type="warning" */>}}
  این API در نسخه بعدی منسوخ خواهد شد.
{{</* /callout */>}}
```

### خطا

{{< callout type="error" >}}
  مشکلی پیش آمد و اتفاقی رخ خواهد شد.
{{< /callout >}}

```markdown
{{</* callout type="error" */>}}
  مشکلی پیش آمد و اتفاقی رخ خواهد شد.
{{</* /callout */>}}
```
